@@ -1,7 +1,6 @@
 import dataclasses
 
-from pydantic import ValidationError
-
+from . import ValidationError, errors
 from .main import create_model, validate_model
 
 
@@ -13,6 +12,21 @@ def _pydantic_post_init(self):
         self.__post_init_original__()
 
 
+def _validate_dataclass(cls, v):
+    if isinstance(v, cls):
+        return v
+    elif isinstance(v, (cls, list, tuple)):
+        return cls(*v)
+    elif isinstance(v, dict):
+        return cls(**v)
+    else:
+        raise errors.DataclassTypeError(class_name=cls.__name__)
+
+
+def _get_validators(cls):
+    yield cls.__validate__
+
+
 def setattr_validate_assignment(self, name, value):
     if self.__initialised__:
         d = dict(self.__dict__)
@@ -24,7 +38,7 @@ def setattr_validate_assignment(self, name, value):
     object.__setattr__(self, name, value)
 
 
-def _process_class(_cls, init, repr, eq, order, unsafe_hash, frozen, validate_assignment):
+def _process_class(_cls, init, repr, eq, order, unsafe_hash, frozen, config):
     post_init_original = getattr(_cls, '__post_init__', None)
     if post_init_original and post_init_original.__name__ == '_pydantic_post_init':
         post_init_original = None
@@ -33,17 +47,20 @@ def _process_class(_cls, init, repr, eq, order, unsafe_hash, frozen, validate_as
 
     fields = {name: (field.type, field.default) for name, field in cls.__dataclass_fields__.items()}
     cls.__post_init_original__ = post_init_original
-    cls.__pydantic_model__ = create_model(cls.__name__, **fields)
-    cls.__initialised__ = False
 
-    if validate_assignment and not frozen:
+    cls.__pydantic_model__ = create_model(cls.__name__, __config__=config, **fields)
+
+    cls.__initialised__ = False
+    cls.__validate__ = classmethod(_validate_dataclass)
+    cls.__get_validators__ = classmethod(_get_validators)
+
+    if cls.__pydantic_model__.__config__.validate_assignment and not frozen:
         cls.__setattr__ = setattr_validate_assignment
+
     return cls
 
 
-def dataclass(
-    _cls=None, *, init=True, repr=True, eq=True, order=False, unsafe_hash=False, frozen=False, validate_assignment=False
-):
+def dataclass(_cls=None, *, init=True, repr=True, eq=True, order=False, unsafe_hash=False, frozen=False, config=None):
     """
     Like the python standard lib dataclasses but with type validation.
 
@@ -52,7 +69,7 @@ def dataclass(
     """
 
     def wrap(cls):
-        return _process_class(cls, init, repr, eq, order, unsafe_hash, frozen, validate_assignment)
+        return _process_class(cls, init, repr, eq, order, unsafe_hash, frozen, config)
 
     if _cls is None:
         return wrap
